pub trait Cowable {
type BorrowHkt: for<'a> BorrowHkt<'a>;
type Owned;
}Expand description
Trait for types that can be used with Cow through a BorrowHkt.
This trait is automatically implemented for types that implement BorrowHkt if BorrowHkt::T implements ToOwned for all lifetimes.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".